@@ -1,6 +1,20 @@
 """VF module instance."""
+#   Copyright 2022 Orange, Deutsche Telekom AG
+#
+#   Licensed under the Apache License, Version 2.0 (the "License");
+#   you may not use this file except in compliance with the License.
+#   You may obtain a copy of the License at
+#
+#       http://www.apache.org/licenses/LICENSE-2.0
+#
+#   Unless required by applicable law or agreed to in writing, software
+#   distributed under the License is distributed on an "AS IS" BASIS,
+#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+#   See the License for the specific language governing permissions and
+#   limitations under the License.
 
 from onapsdk.so.deletion import VfModuleDeletionRequest
+from onapsdk.exceptions import ResourceNotFound
 
 from .instance import Instance
 
@@ -78,6 +92,8 @@ class VfModuleInstance(Instance):  # pylint: disable=too-many-instance-attribute
         self.widget_model_id: str = widget_model_id
         self.widget_model_version: str = widget_model_version
 
+        self._vf_module: "VfModule" = None
+
     def __repr__(self) -> str:
         """Object represetation.
 
@@ -89,6 +105,19 @@ class VfModuleInstance(Instance):  # pylint: disable=too-many-instance-attribute
                 f"is_base_vf_module={self.is_base_vf_module}, "
                 f"automated_assignment={self.automated_assignment})")
 
+    @classmethod
+    def get_all_url(cls, vnf_instance: "VnfInstance") -> str:  # pylint: disable=arguments-differ
+        """Return url to get all vf modules for vnf instance.
+
+        Args:
+            vnf_instance (VnfInstance): VNF instance object
+
+        Returns:
+            str: Url to get all vf modules for vnf instance
+
+        """
+        return f"{vnf_instance.url}/vf-modules/"
+
     @property
     def url(self) -> str:
         """Resource url.
@@ -107,7 +136,18 @@ class VfModuleInstance(Instance):  # pylint: disable=too-many-instance-attribute
             VfModule: VfModule object associated with vf module instance
 
         """
-        return self.vnf_instance.vnf.vf_module
+        if not self._vf_module:
+            for vf_module in self.vnf_instance.vnf.vf_modules:
+                if vf_module.model_version_id == self.model_version_id:
+                    self._vf_module = vf_module
+                    return self._vf_module
+
+            msg = (
+                f'Could not find VF modules for the VF Module instance'
+                f' with model version ID "{self.model_version_id}"'
+            )
+            raise ResourceNotFound(msg)
+        return self._vf_module
 
     @classmethod
     def create_from_api_response(cls,
