@@ -223,7 +223,8 @@ def headers_sdc_artifact_upload(base_header: Dict[str, str], data: str):
     headers["Accept"] = "application/json, text/plain, */*"
     headers["Accept-Encoding"] = "gzip, deflate, br"
     headers["Content-Type"] = "application/json; charset=UTF-8"
-    md5_content = hashlib.new('md5', data.encode('UTF-8'), usedforsecurity=False).hexdigest()
+    md5_content = hashlib.new('md5', data.encode('UTF-8'),        # nosec
+                              usedforsecurity=False).hexdigest()  # nosec
     content = base64.b64encode(md5_content.encode('ascii')).decode('UTF-8')
     headers["Content-MD5"] = content
     return headers
